package com.iamberry.wechat.service.mapper;

import java.util.List;

import com.iamberry.wechat.core.entity.news.News;

/**
 * @author 何秀刚
 * @description ： 新闻Mapper接口 
 * @createDate : 2016年6月13日
 */
public interface NewsMapper {
	
	/**
	 * 获取所有的新闻内容	
	 * @return
	 */
	public List<News> listAll();
	
	/**
	 * 添加新闻
	 * @param news
	 * @return
	 */
	public Integer addNews(News news);
	
	/**
	 * 获取一个新闻内容
	 * @param id
	 * @return
	 */
	public News getOne(Integer id);
	
	/**
	 * 修改
	 * @param news
	 * @return
	 */
	public Integer updateOne(News news);
	
	/**
	 * 递增访问量
	 * @param id
	 * @return
	 */
	public Integer updateAccess(Integer id);
	
	/**
	 * 递增分享量
	 * @param id
	 * @return
	 */
	public Integer updateShare(Integer id);
}
